@@ -1,18 +1,67 @@
+#' Functions for loading and writing Pajek files
+#' 
+#' Functions for reading/loading and writing Pajek files:
+#' 
+#' 
+#' @name Pajek
+NULL
+
+
+#' @rdname Pajek
+#' @description \code{loadnetwork} - Loads a Pajek ".net" filename as a matrix. For now, only simple one and two-mode networks are supported (eg. only single relations, no time information).
+#' 
+#' @aliases Pajek loadnetwork loadnetwork2 loadnetwork3 loadnetwork4 savevector savenetwork savematrix loadmatrix loadvector loadvector2 loadpajek
+#'
+#' @param filename The name of the file to be loaded or saved to or an open file object.
+#' @param useSparseMatrix Should a sparse matrix be use instead of the ordinary one? Sparse matrices can only be used if package Matrix is installed. The default \code{NULL} uses sparse matrices  for networks with more that \code{minN} vertices.
+#' @param minN The minimal number of units in the network to use sparse matrices.
+#'
+#' @return NULL, a matrix or a vector (see Description).
+#'
+#' @references 
+#' Batagelj, V., & Mrvar. A. (1999). Pajek - Program for Large Network Analysis. Retrieved from \url{http://vlado.fmf.uni-lj.si/pub/networks/pajek/}.
+#' 
+#' de Nooy, W., Mrvar, A., & Batagelj. V. (2005). Exploratory Social Network Analysis with Pajek. London: SAGE Publications.
+#' 
+#' @author Vladimir Batagelj & Andrej Mrvar (most functions), \enc{Aleš Žiberna}{Ales Ziberna} (\code{loadnetwork}, \code{loadpajek} and modification of others)
+#' @seealso \code{\link{plot.mat}}, \code{\link{critFunC}}, \code{\link{optRandomParC}}
+#' @keywords graphs file
+#' @import Matrix
+#' @importFrom utils read.table
+#' 
+#' @export
+
 "loadnetwork" <-
 function(filename,useSparseMatrix=NULL,minN=50){
-  n<-read.table(file=filename,nrows=1)
+  trim.trailing <- function (x) sub("\\s+$", "", x)
+
+  n<-c("%")
+  i=0
+  repeat {
+    n<-read.table(file=filename,nrows=1,as.is=TRUE,skip = i)
+    if(substr(n[1],1,1)!="%") break
+    print(paste(n,collapse=" "))
+    i=i+1
+  }
   if(length(n)==2){
     n<-as.numeric(n[2])
-    vnames<-read.table(file=filename,skip=1,nrows=n,as.is =TRUE)[,2]
-    if(all(is.na(vnames))){
-        vnames<-NULL
-    } else vnames[is.na(vnames)]<-""
+    n
     rLines<-readLines(con=filename)
     nl<-length(rLines)
-    ind.stars<-which(regexpr(pattern="*", text=rLines,fixed=TRUE)>0)
+    #ind.stars<-which(regexpr(pattern="*", text=rLines,fixed=TRUE)>0)
+    ind.stars<-which(substr(rLines,1,1)=="*")
     nstars<-length(ind.stars)
     stars<-rLines[ind.stars]
+    stars<-trim.trailing(stars)
     rm(rLines)
+    
+    vnames1<-read.table(file=filename,skip=ind.stars[1],nrows=ind.stars[2]-ind.stars[1]-1,as.is =TRUE)
+    vnames<-character(n)
+    vnames[vnames1[,1]]<-vnames1[,2]
+    if(all(is.na(vnames))){
+      vnames<-NULL
+    } else vnames[is.na(vnames)]<-""
+    
     if(is.null(useSparseMatrix)){
         useSparseMatrix<- n>=50
     }
@@ -49,9 +98,9 @@ function(filename,useSparseMatrix=NULL,minN=50){
       	ties<-ties[,1:3]
       }
       ties<-apply(ties,2,as.numeric)
-      if(stars[i]=="*Arcs"){
+      if(stars[i]=="*Arcs"|stars[i]=="*arcs"){
         M[ties[,1:2]]<-ties[,3]
-      } else if(stars[i]=="*Edges"){
+      } else if(stars[i]=="*Edges"|stars[i]=="*edges"){
         M[ties[,1:2]]<-ties[,3]
         M[ties[,2:1]]<-ties[,3]
       }
@@ -61,17 +110,23 @@ function(filename,useSparseMatrix=NULL,minN=50){
       n12<-as.numeric(n[2])
       n1<-as.numeric(n[3])
       n2<-n12-n1
-      vnames1<-read.table(file=filename,skip=1,nrows=n12)[,2]
-    vnames<-read.table(file=filename,skip=1,nrows=n12,as.is =TRUE)[,2]
-    if(all(is.na(vnames))){
-        vnames<-NULL
-    } else vnames[is.na(vnames)]<-""
+
     rLines<-readLines(con=filename)
     nl<-length(rLines)
-    ind.stars<-which(regexpr(pattern="*", text=rLines,fixed=TRUE)>0)
+    #ind.stars<-which(regexpr(pattern="*", text=rLines,fixed=TRUE)>0)
+    ind.stars<-which(substr(rLines,1,1)=="*")
     nstars<-length(ind.stars)
     stars<-rLines[ind.stars]
     rm(rLines)
+    
+    vnames1<-read.table(file=filename,skip=ind.stars[1],nrows=ind.stars[2]-ind.stars[1]-1,as.is =TRUE)
+    vnames<-character(n12)
+    vnames[vnames1[,1]]<-vnames1[,2]
+    if(all(is.na(vnames))){
+      vnames<-NULL
+    } else vnames[is.na(vnames)]<-""
+    
+    
     if(is.null(useSparseMatrix)){
         useSparseMatrix<- n12>50
     }    
