@@ -1,6 +1,8 @@
-"plot.opt.more.par" <-
+#' @rdname plotMat
+#' @export
+"plot.optMorePar" <-
 function(
-	x,#an "opt.par.mode" class object
+	x,#an "optParMode" class object
 	main=NULL,
 	which=1,	#which (if there are more than one) of optimal solutions to plot
 	...	#aditional parameters to "plot.mat"
@@ -13,3 +15,8 @@ function(
 	plot.mat(x$M,clu=clu(x,which=which),IM=x$best[[which]]$IM,main=main,...)
 }
 
+
+#' @rdname plotMat
+#' @method plot opt.more.par
+#' @export
+plot.opt.more.par<-plot.optMorePar
\ No newline at end of file
